@@ -578,7 +578,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
     def get_datacard(self, slug):
 
-        url = self.smart_insight_url + "/definitions/insight-slugs/" + slug +"?agentId=" + self._agentId + "&definitionOnly=true"
+        url = self.smart_insight_url + "/insight-slugs/" + slug +"?agentId=" + self._agentId
 
         s = requests.Session()
         s.keep_alive = False
